#!/usr/bin/env python

"""
`webbrowser` Documentation:  http://docs.python.org/library/webbrowser.html

This file should open up your web browser, create a new tab, and load my
website.
"""

import webbrowser

webbrowser.open('http://www.importscreencast.com', new=2)
